searchNodes=[{"doc":"This library implements some fast avro access functions to be used in conjuction with avro_ex or schema_avro libraries. It just contains some convenience functions useful when having high amount of avro records to process. It allows faster access than the pure elixir libraries for use cases like: You need only to read one or a small amount of fields from the avro data but no modify it. As an example you just need to retrieve some time field to use it as partitioning value in your destination system. You want to simplify the message by extracting some fields and reencode with a diferent schema. To obtain that speed gain, FastAvro uses a rust wrapper arround the apache-avro for rust library . It only supports 'record' type at first level of the schema and only primitive types 'string', 'int', 'long' and 'double' as field types. { &quot;type&quot;: &quot;record&quot;, &quot;name&quot;: &quot;person&quot;, &quot;fields&quot; : [ {&quot;name&quot;: &quot;name&quot;, &quot;type&quot;: &quot;string&quot;}, {&quot;name&quot;: &quot;age&quot;, &quot;type&quot;: &quot;int&quot;}, {&quot;name&quot;: &quot;score&quot;, &quot;type&quot;: &quot;double&quot;} ] }","ref":"FastAvro.html","title":"FastAvro","type":"module"},{"doc":"Creates a new avro record from a map of field names as string binaries and values compatible with the given schema. All mandatory fields must be provided and the asociated values must correctly typed. Parameters map: an elixir map with fields to be populated schema: a schema() reference for the record format Returns {:ok, avro_record} : an avro_record() reference already populated and ready to be encoded. {:error, :wrong_type} : if the schema contains an unknown data type. Examples iex&gt; { :ok , record } = FastAvro . create_msg ( %{ &quot;name&quot; =&gt; &quot;John&quot; , &quot;age&quot; =&gt; 25 , &quot;score&quot; =&gt; 5.6 } , schema ) { :ok , # Reference &lt; 0.2515214245 . 918683654.17019 &gt; }","ref":"FastAvro.html#create_msg/2","title":"FastAvro.create_msg/2","type":"function"},{"doc":"Decodes avro data given as a binary using the provided schema. It decodes only raw data without any headers, no schema and no fingerprint. Parameters binary : valid avro data as a binary schema : a schema() reference for a record definition compatible with the data. Returns {:ok, avro_record()} : when successfully decoded {:error, :incompatible_avro_schema} : when schema not valid to decode data {:error, :all_data_not_read} : if the decode has not read all the binary Examples iex&gt; FastAvro . decode_avro_datum ( avro_data , schema ) { :ok , # Reference &lt; 0.2887345315 . 2965241864.83696 &gt; }","ref":"FastAvro.html#decode_avro_datum/2","title":"FastAvro.decode_avro_datum/2","type":"function"},{"doc":"Encodes avro data from a map using the provided schema. It raw encodes the data without any headers, no schema and no fingerprint. Parameters map : elixir map with field names and values to encode schema : a schema() reference compatible with the fields and values in the map. Returns {:ok, binary} : binary contains avro representation of the data in the map as described by the schema. {:error, :wrong_type} : the schema contains an unsupported data type {:error, :incompatible_avro_schema} : the schema does not match map contents {:error, :field_not_found} : if map field missing from schema Examples iex&gt; FastAvro . encode_avro_datum ( %{ &quot;tac&quot; =&gt; 1432 , &quot;from&quot; =&gt; &quot;2023-01-25 00:45:52&quot; , &quot;to&quot; =&gt; &quot;2023-01-25 01:00:00&quot; } , new_schema ) { :ok , &lt;&lt; 176 , 22 , 38 , 50 , 48 , 50 , 51 , 45 , 48 , 49 , 45 , 50 , 53 , 32 , 48 , 48 , 58 , 52 , 53 , 58 , 53 , 50 , 38 , 50 , 48 , 50 , 51 , 45 , 48 , 49 , 45 , 50 , 53 , 32 , 48 , 49 , 58 , 48 , 48 , 58 , 48 , 48 &gt;&gt; }","ref":"FastAvro.html#encode_avro_datum/2","title":"FastAvro.encode_avro_datum/2","type":"function"},{"doc":"Gets the value associated to a field name from a given avro record. Parameters avro_record : a avro_record() reference already decoded name : the field name to consult as a string Returns {:ok, term} : term representing the value of the field in the avro record {:error, :field_not_found} : If the field does not exist in the avro record {:error, :not_a_record} : If the binary is not an avro record Examples iex&gt; FastAvro . get_avro_value ( msg , &quot;Dest_TAC&quot; ) { :ok , &quot;TAC: 1142&quot; }","ref":"FastAvro.html#get_avro_value/2","title":"FastAvro.get_avro_value/2","type":"function"},{"doc":"Gets the value associated to a field name from given avro data and schema. Parameters binary : valid avro data as a binary schema : a schema() reference compatible with that avro data. name : the field name to consult as a string Returns {:ok, term} : term representing the value of the field in the avro record {:error, :field_not_found} : If the field does not exist in the avro record {:error, :not_a_record} : If the binary is not an avro record {:error, :incompatible_avro_schema} : If the schema is not compatible with the binary {:error, :all_data_not_read} : if the decode has not read all the binary Examples iex&gt; FastAvro . get_raw_value ( avro_binary , &quot;Dest_TAC&quot; ) { :ok , &quot;TAC: 1142&quot; }","ref":"FastAvro.html#get_raw_value/3","title":"FastAvro.get_raw_value/3","type":"function"},{"doc":"Gets the values associated with a list of field names from given avro data and schema. Parameters avro_binary : valid avro data as a binary schema : a schema() reference compatible with that avro data. names : a list of field names to consult as a strings Returns {:ok, map} : a map with field names and values extracted from avro_binary {:error, :not_a_record} : if avro_binary is not an avro record {:error, :field_not_found} : if a name in names is not in the schema If the field does not exists in the avro record you get :field_not_found. Examples iex&gt; FastAvro . get_raw_values ( avro_data , schema , [ &quot;Dest_TAC&quot; , &quot;Event_Start&quot; , &quot;Event_Stop&quot; ] ) { :ok , %{ &quot;Dest_TAC&quot; =&gt; &quot;TAC: 1142&quot; , &quot;Event_Start&quot; =&gt; &quot;20200914 18:03:03.174&quot; , &quot;Event_Stop&quot; =&gt; &quot;20200914 18:03:03.224&quot; }","ref":"FastAvro.html#get_raw_values/3","title":"FastAvro.get_raw_values/3","type":"function"},{"doc":"This function parses and validates a avro schema given as a json encoded string. It returns creates an internal representation of the schema ready to be used with FastAvro.create_msg/2 or FastAvro.decode_avro_datum/2 . Parameters json: a string containing the schema definition json encoded. Returns {:ok, schema} {:error, reason} Examples iex&gt; { :ok , schm } = File . read! ( &quot;bench/lte_202210.avsc&quot; ) |&gt; FastAvro . read_schema { :ok , # Reference &lt; 0.3029127103 . 749076481.152983 &gt; } In order to interoperate with the rest of the module the schema must define a 'record' with only primitive 'string', 'int', 'long' and 'double' fields.","ref":"FastAvro.html#read_schema/1","title":"FastAvro.read_schema/1","type":"function"},{"doc":"Given a schema it makes a list of fields and their types. Parameters schema: a schema() reference. Resturns A map with field names and types as string binaries. Examples iex&gt; FastAvro . schema_fields ( schema ) %{ &quot;S1_Attach_Attempt&quot; =&gt; &quot;Int&quot; , &quot;Report_Reason&quot; =&gt; &quot;Int&quot; , &quot;Dest_Cell_Id&quot; =&gt; &quot;String&quot; , &quot;NRN_llamante&quot; =&gt; &quot;String&quot; , &quot;Dest_SAC&quot; =&gt; &quot;String&quot; } This is useful if you need to instrospect the schema.","ref":"FastAvro.html#schema_fields/1","title":"FastAvro.schema_fields/1","type":"function"},{"doc":"Converts an avro_record() reference into an elixir map. Parameters avro_record : an avro_record() reference to convert. Retunrs An elixir map with avro field names as keys and avro field values as values. Examples iex&gt; FastAvro . to_map ( msg ) %{ &quot;S1_Attach_Attempt&quot; =&gt; 0 , &quot;Report_Reason&quot; =&gt; 19 , &quot;Dest_Cell_Id&quot; =&gt; &quot;&quot; , &quot;NRN_llamante&quot; =&gt; &quot;&quot; , &quot;Dest_SAC&quot; =&gt; &quot;TAC: 1142&quot; , }","ref":"FastAvro.html#to_map/1","title":"FastAvro.to_map/1","type":"function"},{"doc":"Is a decoded and schema validated avro record","ref":"FastAvro.html#t:avro_record/0","title":"FastAvro.avro_record/0","type":"type"},{"doc":"Is a precompiled and validated avro schema","ref":"FastAvro.html#t:schema/0","title":"FastAvro.schema/0","type":"type"}]